@@ -158,8 +158,6 @@ class API(object):
         input_json is either a dict or a file
         accession is unique name that we be part of run id
         '''
-        if not jobid:
-            jobid = create_jobid()
         if isinstance(input_json, dict):
             data = copy.deepcopy(input_json)
         elif isinstance(input_json, str) and os.path.exists(input_json):
@@ -167,6 +165,15 @@ class API(object):
                 data = json.load(input_file)
         else:
             raise Exception("input json must be either a file or a dictionary")
+        # jobid can be specified through run_workflow option (priority),
+        # or in input_json
+        if not jobid:
+            if 'jobid' in data:
+                jobid = data['jobid']
+            else:
+                jobid = create_jobid()
+        data['jobid'] = jobid
+
         if not sfn:
             sfn = self.default_stepfunction_name
         if not env:
@@ -189,8 +196,6 @@ class API(object):
         # calculate what the url will be
         url = "%s%s" % (base_url, arn)
         data[_tibanna]['url'] = url
-        # add jobid
-        data['jobid'] = jobid
         if 'args' in data:  # unicorn-only
             unicorn_input = UnicornInput(data)
             args = unicorn_input.args
@@ -223,7 +228,7 @@ class API(object):
                 "aws_region": AWS_REGION
             }
             costupdater_input = json.dumps(costupdater_input)
-            response = client.start_execution(
+            costupdater_response = client.start_execution(
                 stateMachineArn=STEP_FUNCTION_ARN(sfn + "_costupdater"),
                 name=run_name,
                 input=costupdater_input,
@@ -600,7 +605,7 @@ class API(object):
 
     def rerun(self, exec_arn=None, job_id=None, sfn=None,
               override_config=None, app_name_filter=None,
-              instance_type=None, shutdown_min=None, ebs_size=None, ebs_type=None, ebs_iops=None,
+              instance_type=None, shutdown_min=None, ebs_size=None, ebs_type=None, ebs_iops=None, ebs_throughput=None,
               overwrite_input_extra=None, key_name=None, name=None, use_spot=None, do_not_use_spot=None):
         """rerun a specific job
         override_config : dictionary for overriding config (keys are the keys inside config)
@@ -645,6 +650,8 @@ class API(object):
                     override_config['ebs_iops'] = ''
             if ebs_iops:
                 override_config['ebs_iops'] = ebs_iops
+            if ebs_throughput:
+                override_config['ebs_throughput'] = ebs_throughput
             if use_spot:
                 override_config['spot_instance'] = True
             if do_not_use_spot:
@@ -657,7 +664,7 @@ class API(object):
     def rerun_many(self, sfn=None, stopdate='13Feb2018', stophour=13,
                    stopminute=0, offset=0, sleeptime=5, status='FAILED',
                    override_config=None, app_name_filter=None,
-                   instance_type=None, shutdown_min=None, ebs_size=None, ebs_type=None, ebs_iops=None,
+                   instance_type=None, shutdown_min=None, ebs_size=None, ebs_type=None, ebs_iops=None, ebs_throughput=None,
                    overwrite_input_extra=None, key_name=None, name=None, use_spot=None, do_not_use_spot=None):
         """Reruns step function jobs that failed after a given time point
         (stopdate, stophour (24-hour format), stopminute)
@@ -684,7 +691,7 @@ class API(object):
                 self.rerun(exc['executionArn'], sfn=sfn,
                            override_config=override_config, app_name_filter=app_name_filter,
                            instance_type=instance_type, shutdown_min=shutdown_min, ebs_size=ebs_size,
-                           ebs_type=ebs_type, ebs_iops=ebs_iops,
+                           ebs_type=ebs_type, ebs_iops=ebs_iops, ebs_throughput=ebs_throughput,
                            overwrite_input_extra=overwrite_input_extra, key_name=key_name, name=name,
                            use_spot=use_spot, do_not_use_spot=do_not_use_spot)
                 time.sleep(sleeptime)
@@ -801,7 +808,10 @@ class API(object):
             client = boto3.client('s3')
             for b in bucket_names:
                 logger.info("Deleting public access block for bucket %s" % b)
-                response = client.delete_public_access_block(Bucket=b)
+                try:
+                    response = client.delete_public_access_block(Bucket=b)
+                except Exception as e:
+                    logger.warning("public access block could not be deleted on bucket %s - skipping.." % b)
         tibanna_iam = self.IAM(usergroup_tag, bucket_names, no_randomize=no_randomize)
         tibanna_iam.create_tibanna_iam(verbose=verbose)
         logger.info("Tibanna usergroup %s has been created on AWS." % tibanna_iam.user_group_name)
